# Shift Management

Generate and manage shifts for cooperators.

Table of contents

- Configuration
- Changelog
  - 12.0.2.1.0 (2022-06-21)
- Bug Tracker
- Credits
  - Authors
  - Contributors
  - Maintainers

# Configuration

- Translate cooperative status selection field, the terms to translate are:
  - shift_status_up_to_date,
  - shift_status_holidays,
  - shift_status_warning,
  - shift_status_extension,
  - shift_status_suspended,
  - shift_status_exempted,
  - shift_status_unsubscribed,
  - shift_status_resigning.
- Configure “Send weekly shift summary” cron:
  - Its interval number (default = 7) should be consistent with notice (default = 1) and period (default = 7).

# Changelog

## 12.0.2.1.0 (2022-06-21)

Features

- When subscribing a worker to a shift template in the backend : if no super cooperator is set on template and worker is super cooperator automatically set them as super cooperator. The worker must have a user linked to it. (#303)

12.0.1.1.4 (2022-05-26) Bugfixes

- When changing a regular worker to an irregular worker via the wizard, no longer give an error when their (former) shift is full. (#390)

12.0.1.1.1 (2022-05-26) Bugfixes

- No longer raise an error when unsubscribing a replacement worker using the wizard. (#389)

# Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us to smash it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

# Credits

## Authors

- Thibault Francois
- Elouan Le Bars
- Coop IT Easy SC

## Contributors

- BEES coop - Cellule IT
- Coop IT Easy SC

## Maintainers

This module is part of the beescoop/Obeesdoo project on GitHub.

You are welcome to contribute.